@@ -290,6 +290,7 @@ my $additions_maj =
    "69",
    "7",
    "711",
+   "7add11",
    "7#11",
    "7#5",
    "7#9",
@@ -345,7 +346,7 @@ my $additions_maj =
    "h",
    "h7",
    "h9",
-   ( map { "add$_"   }     "2", "4", "9" ),
+   ( map { "add$_"   }     "2", "4", "9", "11" ),
    ( map { "sus$_"   } "", "2", "4", "9" ),
    ( map { "6sus$_"  } "", "2", "4" ),
    ( map { "7sus$_"  } "", "2", "4" ),
