@@ -759,8 +759,10 @@ sub decompose_grid {
 my %abbrevs = (
    c	      => "comment",
    cb	      => "comment_box",
+   cf	      => "chordfont",
    ci	      => "comment_italic",
    colb	      => "column_break",
+   cs	      => "chordsize",
    eob	      => "end_of_bridge",
    eoc	      => "end_of_chorus",
    eot	      => "end_of_tab",
@@ -777,7 +779,9 @@ my %abbrevs = (
    sov	      => "start_of_verse",
    st	      => "subtitle",
    t	      => "title",
-);
+   tf         => "textfont",
+   ts         => "textsize",
+	      );
 
 
 sub parse_directive {
@@ -1295,8 +1299,18 @@ sub directive {
 	while ( @a ) {
 	    my $a = shift(@a);
 
+	    # Copy existing definition.
+	    if ( $a eq "copy" ) {
+		unless ( App::Music::ChordPro::Chords::_known_chord($a[0]) ) {
+		    do_warn("Unknown chord to copy: $a[0]\n");
+		    $fail++;
+		    last;
+		}
+		$res->{copy} = shift(@a);
+	    }
+
 	    # base-fret N
-	    if ( $a eq "base-fret" ) {
+	    elsif ( $a eq "base-fret" ) {
 		if ( $a[0] =~ /^\d+$/ ) {
 		    $res->{base} = shift(@a);
 		}
@@ -1371,12 +1385,18 @@ sub directive {
 
 	return 1 if $fail;
 
-	if ( ( $res->{fingers} || $res->{base} ) && ! $res->{frets} ) {
-	    do_warn("Missing fret positions: $res->{name}\n");
+	unless ( $res->{copy} ||$res->{frets} || $res->{keys} ) {
+	    do_warn("Incomplete chord definition: $res->{name}\n");
 	    return 1;
 	}
 
 	if ( $show) {
+	    if ( $res->{copy} ) {
+		my $r = App::Music::ChordPro::Chords::chord_info($res->{copy});
+		do_warn("Cannot copy $res->{copy}"), return 1
+		  unless $r;
+		$res = { %$r, name => $res->{name} };
+	    }
 	    my $ci;
 	    if ( $res->{frets} || $res->{base} || $res->{fingers} ) {
 		$ci = { name  => $res->{name},
@@ -1404,7 +1424,7 @@ sub directive {
 	}
 
 	if ( $res->{frets} || $res->{fingers} || $res->{keys} ) {
-	    $res->{base} ||= 1;
+	    $res->{base} ||= 1 unless $res->{copy};
 	    push( @{$song->{define}}, $res );
 	    my $ret =
 	      App::Music::ChordPro::Chords::add_song_chord($res);
